==> deepin-update-ui_1.0.12.tar.xz: BUILD/src/dde-update/translations/dde-update_az.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="az">
<context>
    <name>CheckProgressWidget</name>
    <message>
        <source>The check is almost complete, thank you for your patience</source>
        <translation>Yoxlama başa çatmaq üzrədir, səbrlə gözlədiyiniz üçün təşəkkür edirik</translation>
    </message>
    <message>
        <source>Preparing</source>
        <translation>Hazırlıq</translation>
    </message>
</context>
<context>
    <name>ErrorFrame</name>
    <message>
        <source>Checked for some errors</source>
        <translation>Bəzi səhvlər yoxlanıldı</translation>
    </message>
</context>
<context>
    <name>SuccessFrame</name>
    <message>
        <source>Go to Desktop</source>
        <translation>İş masasına keçin</translation>
    </message>
    <message>
        <source>Welcome, system updated successfully</source>
        <translation>Xoş Gəldiniz, sistem yenilənməsi uğurlu oldu</translation>
    </message>
    <message>
        <source>Current Edition:</source>
        <translation>Cari buraxılış:</translation>
    </message>
</context>
<context>
    <name>UpdateCompleteWidget</name>
    <message>
        <source>View Logs</source>
        <translation>Jurnal qeydlərinə baxış</translation>
    </message>
    <message>
        <source>Updates successful</source>
        <translation>Yenilənmə uğurlu oldu</translation>
    </message>
    <message>
        <source>Your computer will reboot soon %1</source>
        <translation>Kompyuteriniz tezliklə yenidən başladılacaqdır: %1</translation>
    </message>
    <message>
        <source>Your computer will be turned off soon %1</source>
        <translation>Komppyuteriniz tezliklə sönəcəkdir: %1</translation>
    </message>
    <message>
        <source>The automatic reboot process has failed. Please try to manually reboot your device.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>The automatic shutdown process has failed. Please try to manually shut down your device.</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>UpdateLogWidget</name>
    <message>
        <source>Hide Logs</source>
        <translation>Jurnal qeydlərini gizlətmək</translation>
    </message>
</context>
<context>
    <name>UpdateModel</name>
    <message>
        <source>Update failed</source>
        <translation>فشل التحديث</translation>
    </message>
    <message>
        <source>Unknown error</source>
        <translation>Naməlum xəta</translation>
    </message>
    <message>
        <source>Backup failed</source>
        <translation>Ehtiyyat nüsxələmə mümkün olmadı</translation>
    </message>
    <message>
        <source>Unable to perform system backup. If you continue the updates, you cannot roll back to the old system later.</source>
        <translation>Sistemin ehtiyyat nüsxəsinin saxlanılmasını icra etmək mümkün olmadı. Əgər yeniləməyə davam etsəniz geri, köhnə sistemə qayıda bilməyəcəksiniz?</translation>
    </message>
    <message>
        <source>Insufficient disk space. Please clean up your disk and try again.</source>
        <translation>Disk sahəsi kifayət etmir. Diskinizi təmizləyin və yenidən cəhd edin</translation>
    </message>
    <message>
        <source>Failed to connect to backup services. Please check and retry again.</source>
        <translation>Ehtiyyat nüsxələmə xidmətləri ilə bağlantı baş tutmadı. Lütfən yoxlayın və yenidən cəhd edin.</translation>
    </message>
    <message>
        <source>Failed to connect to update services. Please check and retry again.</source>
        <translation>Yenilənmə xidmətləri ilə bağlantı alınmadı. Lütfən, yoxlayın və yenidən cəhd edin.</translation>
    </message>
    <message>
        <source>Dependency error</source>
        <translation>Asılılıq xətası</translation>
    </message>
    <message>
        <source>DPKG error</source>
        <translation>DPKG xətası</translation>
    </message>
    <message>
        <source>Back Up Again</source>
        <translation>Yenidən ehtiyyat nüsxə yaradın</translation>
    </message>
    <message>
        <source>Abort</source>
        <translation>Ləğv edin</translation>
    </message>
    <message>
        <source>Proceed to Update</source>
        <translation>Yenilənməyə davam edin</translation>
    </message>
    <message>
        <source>Reboot</source>
        <translation>Yenidən başlat</translation>
    </message>
    <message>
        <source>Shut Down</source>
        <translation>Söndür</translation>
    </message>
    <message>
        <source>Go to Desktop</source>
        <translation>İş masasına keçin</translation>
    </message>
</context>
<context>
    <name>UpdatePrepareWidget</name>
    <message>
        <source>Preparing for updates…</source>
        <translation>Yenilənmələr üçün hazırlıq...</translation>
    </message>
</context>
<context>
    <name>UpdateProgressWidget</name>
    <message>
        <source>Do not force a shutdown or power off when installing updates. Otherwise, your system may be damaged.</source>
        <translation>Yenilənmələr quraşdırılan zaman məcburi söndürmək və ya yenidən başlatmaq olmaz. Əks halda sisteminiz sıradan çıxa bilər.</translation>
    </message>
</context>
</TS>

==> deepin-update-ui_1.0.38.1.tar.xz: BUILD/src/dde-update/translations/dde-update_az.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="az">
<context>
    <name>CheckProgressWidget</name>
    <message>
        <source>The check is almost complete, thank you for your patience</source>
        <translation>Yoxlama başa çatmaq üzrədir, səbrlə gözlədiyiniz üçün təşəkkür edirik</translation>
    </message>
    <message>
        <source>Preparing</source>
        <translation>Hazırlıq</translation>
    </message>
</context>
<context>
    <name>ErrorFrame</name>
    <message>
        <source>Checked for some errors</source>
        <translation>Bəzi səhvlər yoxlanıldı</translation>
    </message>
</context>
<context>
    <name>SuccessFrame</name>
    <message>
        <source>Go to Desktop</source>
        <translation>İş masasına keçin</translation>
    </message>
    <message>
        <source>Welcome, system updated successfully</source>
        <translation>Xoş Gəldiniz, sistem yenilənməsi uğurlu oldu</translation>
    </message>
    <message>
        <source>Current Edition:</source>
        <translation>Cari buraxılış:</translation>
    </message>
</context>
<context>
    <name>UpdateCompleteWidget</name>
    <message>
        <source>Updates successful</source>
        <translation>Yenilənmə uğurlu oldu</translation>
    </message>
    <message>
        <source>Your computer will reboot soon %1</source>
        <translation>Kompyuteriniz tezliklə yenidən başladılacaqdır: %1</translation>
    </message>
    <message>
        <source>Your computer will be turned off soon %1</source>
        <translation>Komppyuteriniz tezliklə sönəcəkdir: %1</translation>
    </message>
    <message>
        <source>The automatic reboot process has failed. Please try to manually reboot your device.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>The automatic shutdown process has failed. Please try to manually shut down your device.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>View update logs</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Collapse update logs</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>UpdateLogWidget</name>
    <message>
        <source>Export</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>The log has been exported to the desktop</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Log export failed, please try again</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>UpdateModel</name>
    <message>
        <source>Update failed</source>
        <translation>فشل التحديث</translation>
    </message>
    <message>
        <source>Unknown error</source>
        <translation>Naməlum xəta</translation>
    </message>
    <message>
        <source>Backup failed</source>
        <translation>Ehtiyyat nüsxələmə mümkün olmadı</translation>
    </message>
    <message>
        <source>Unable to perform system backup. If you continue the updates, you cannot roll back to the old system later.</source>
        <translation>Sistemin ehtiyyat nüsxəsinin saxlanılmasını icra etmək mümkün olmadı. Əgər yeniləməyə davam etsəniz geri, köhnə sistemə qayıda bilməyəcəksiniz?</translation>
    </message>
    <message>
        <source>Insufficient disk space. Please clean up your disk and try again.</source>
        <translation>Disk sahəsi kifayət etmir. Diskinizi təmizləyin və yenidən cəhd edin</translation>
    </message>
    <message>
        <source>Failed to connect to backup services. Please check and retry again.</source>
        <translation>Ehtiyyat nüsxələmə xidmətləri ilə bağlantı baş tutmadı. Lütfən yoxlayın və yenidən cəhd edin.</translation>
    </message>
    <message>
        <source>Failed to connect to update services. Please check and retry again.</source>
        <translation>Yenilənmə xidmətləri ilə bağlantı alınmadı. Lütfən, yoxlayın və yenidən cəhd edin.</translation>
    </message>
    <message>
        <source>Dependency error</source>
        <translation>Asılılıq xətası</translation>
    </message>
    <message>
        <source>DPKG error</source>
        <translation>DPKG xətası</translation>
    </message>
    <message>
        <source>Back Up Again</source>
        <translation>Yenidən ehtiyyat nüsxə yaradın</translation>
    </message>
    <message>
        <source>Abort</source>
        <translation>Ləğv edin</translation>
    </message>
    <message>
        <source>Proceed to Update</source>
        <translation>Yenilənməyə davam edin</translation>
    </message>
    <message>
        <source>Reboot</source>
        <translation>Yenidən başlat</translation>
    </message>
    <message>
        <source>Shut Down</source>
        <translation>Söndür</translation>
    </message>
    <message>
        <source>Go to Desktop</source>
        <translation>İş masasına keçin</translation>
    </message>
</context>
<context>
    <name>UpdatePrepareWidget</name>
    <message>
        <source>Preparing for updates…</source>
        <translation>Yenilənmələr üçün hazırlıq...</translation>
    </message>
</context>
<context>
    <name>UpdateProgressWidget</name>
    <message>
        <source>Do not force a shutdown or power off when installing updates. Otherwise, your system may be damaged.</source>
        <translation>Yenilənmələr quraşdırılan zaman məcburi söndürmək və ya yenidən başlatmaq olmaz. Əks halda sisteminiz sıradan çıxa bilər.</translation>
    </message>
    <message>
        <source>View update logs</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Collapse update logs</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>UpdateWorker</name>
    <message>
        <source>updatelog</source>
        <translation type="unfinished"/>
    </message>
</context>
</TS>
